sonos_extras
============

.. image:: https://img.shields.io/pypi/v/sonos_extras.svg
    :target: https://pypi.python.org/pypi/sonos_extras
    :alt: Latest PyPI version

.. image:: ''.png
   :target: ''
   :alt: Latest Travis CI build status

Some extra useful commands for Sonos systems, based on SoCo.

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`sonos_extras` was written by `MaziarA <maziara2@gmail.com>`_.
